==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__24MessageIcon.h <==
// class javax.swing.plaf.basic.BasicOptionPaneUI$MessageIcon

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7173f5e939a87bd6 javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *);
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$_init$f7d4530039b34981(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *);

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *);
extern jint _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *);
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *);
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *);
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicOptionPaneUI__24MessageIcon.h <==
// class javax.swing.plaf.basic.BasicOptionPaneUI$MessageIcon

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dfbd93626158fee3 javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon_H_
#define _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$_init$f7d4530039b34981(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *) _JC_JCNI_ATTR;
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *) _JC_JCNI_ATTR;
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vmethods	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs {
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_refs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$sub_nonrefs	javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$object {
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$vtype _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicOptionPaneUI__24MessageIcon_H_ */
